@@ -20,9 +20,9 @@ import blockdiag.drawer
 import blockdiag.parser
 from blockdiag.utils.bootstrap import Application, Options
 
-# for compatibility
-from blockdiag.utils.bootstrap import create_fontmap, detectfont
-create_fontmap
+
+# FIXME: for compatibility
+from blockdiag.utils.bootstrap import detectfont
 detectfont
 
 
