@@ -16,12 +16,14 @@
 import re
 import math
 from itertools import izip, tee
-from functools import wraps
-from blockdiag.imagedraw import base, textfolder
-from blockdiag.imagedraw.utils import cached
-from blockdiag.utils import ellipse, urlutil, Box, Size, XY
+from blockdiag.imagedraw import base
+from blockdiag.imagedraw.utils import cached, ellipse
+from blockdiag.imagedraw.utils.ellipse import dots as ellipse_dots
+from blockdiag.utils import urlutil, Box, Size, XY
 from blockdiag.utils.fontmap import parse_fontpath, FontMap
+from blockdiag.utils.functools import partial, wraps
 from blockdiag.utils.myitertools import istep, stepslice
+
 try:
     from PIL import Image
     from PIL import ImageDraw
@@ -166,7 +168,7 @@ class ImageDrawExBase(base.ImageDraw):
                 end += 360
 
             cycle = style2cycle(style, kwargs.get('width'))
-            for pt in ellipse.dots(box, cycle, start, end):
+            for pt in ellipse_dots(box, cycle, start, end):
                 self.draw.line([pt, pt], fill=kwargs['fill'])
         else:
             self.draw.arc(box, start, end, **kwargs)
@@ -191,7 +193,7 @@ class ImageDrawExBase(base.ImageDraw):
                 del kwargs['outline']
 
             cycle = style2cycle(style, kwargs.get('width'))
-            for pt in ellipse.dots(box, cycle):
+            for pt in ellipse_dots(box, cycle):
                 self.draw.line([pt, pt], fill=kwargs['fill'])
         else:
             if kwargs.get('fill') == 'none':
@@ -268,14 +270,10 @@ class ImageDrawExBase(base.ImageDraw):
             del kwargs['outline']
             self.line(xy, **kwargs)
 
-    def textsize(self, string, font, maxwidth=None, **kwargs):
-        if maxwidth is None:
-            maxwidth = 65535
-
-        box = Box(0, 0, maxwidth, 65535)
-        textbox = textfolder.get(self, box, string, font,
-                                 scale=self.scale_ratio, **kwargs)
-        return textbox.outlinebox.size
+    @property
+    def textfolder(self):
+        textfolder = super(ImageDrawExBase, self).textfolder
+        return partial(textfolder, scale=self.scale_ratio)
 
     @cached
     def textlinesize(self, string, font):
@@ -306,9 +304,8 @@ class ImageDrawExBase(base.ImageDraw):
                 draw.text((0, 0), string, fill=fill)
                 del draw
 
-                font_ratio = font.size * 1.0 / FontMap.BASE_FONTSIZE
-                basesize = (int(size[0] * self.scale_ratio * font_ratio),
-                            int(size[1] * self.scale_ratio * font_ratio))
+                basesize = (size[0] * self.scale_ratio,
+                            size[1] * self.scale_ratio)
                 text_image = image.resize(basesize, Image.ANTIALIAS)
                 self.paste(text_image, xy, text_image)
         else:
@@ -342,8 +339,7 @@ class ImageDrawExBase(base.ImageDraw):
             self.paste(filler, box.topleft, text._image.rotate(angle))
             return
 
-        lines = textfolder.get(self, box, string, font,
-                               scale=self.scale_ratio, **kwargs)
+        lines = self.textfolder(box, string, font, **kwargs)
 
         if kwargs.get('outline'):
             outline = kwargs.get('outline')
