@@ -15,17 +15,70 @@
 
 import re
 import base64
-from blockdiag.imagedraw import base as _base, textfolder
+from blockdiag.imagedraw import base as _base
 from blockdiag.imagedraw.simplesvg import *
 from blockdiag.imagedraw.utils import cached
+from blockdiag.imagedraw.utils.ellipse import endpoints as ellipse_endpoints
 from blockdiag.utils import urlutil, Box, XY
+from blockdiag.utils.functools import partial
 
 feGaussianBlur = svgclass('feGaussianBlur')
 
 
+def rgb(color):
+    if isinstance(color, tuple):
+        color = 'rgb(%d,%d,%d)' % color
+
+    return color
+
+
+def style(name):
+    if name == 'blur':
+        value = "filter:url(#filter_blur)"
+    elif name == 'transp-blur':
+        value = "filter:url(#filter_blur);opacity:0.7;fill-opacity:1"
+    else:
+        value = None
+
+    return value
+
+
+def dasharray(pattern, thick):
+    if thick is None:
+        thick = 1
+
+    if pattern == 'dotted':
+        value = 2 * thick
+    elif pattern == 'dashed':
+        value = 4 * thick
+    elif pattern == 'none':
+        value = "%d %d" % (0, 65535 * thick)
+    elif re.search('^\d+(,\d+)*$', pattern or ""):
+        l = [int(n) * thick for n in pattern.split(",")]
+        value = " ".join(str(n) for n in l)
+    else:
+        value = None
+
+    return value
+
+
+def drawing_params(kwargs):
+    params = {}
+
+    if 'style' in kwargs:
+        params['stroke_dasharray'] = dasharray(kwargs.get('style'),
+                                               kwargs.get('thick'))
+
+    if 'filter' in kwargs:
+        params['style'] = style(kwargs.get('filter'))
+
+    return params
+
+
 class SVGImageDrawElement(_base.ImageDraw):
     self_generative_methods = ['group', 'anchor']
     supported_path = True
+    baseline_text_rendering = True
 
     def __init__(self, svg, parent=None):
         self.svg = svg
@@ -34,79 +87,24 @@ class SVGImageDrawElement(_base.ImageDraw):
         else:
             self.ignore_pil = False
 
-    def rgb(self, color):
-        if isinstance(color, tuple):
-            color = 'rgb(%d,%d,%d)' % color
-
-        return color
-
-    def filter(self, name):
-        if name == 'blur':
-            _filter = "filter:url(#filter_blur)"
-        elif name == 'transp-blur':
-            _filter = "filter:url(#filter_blur);opacity:0.7;fill-opacity:1"
-        else:
-            _filter = None
-
-        return _filter
-
-    def style(self, name, thick):
-        if thick is None:
-            thick = 1
-
-        if name == 'dotted':
-            length = 2 * thick
-        elif name == 'dashed':
-            length = 4 * thick
-        elif name == 'none':
-            length = "%d %d" % (0, 65535 * thick)
-        elif re.search('^\d+(,\d+)*$', name or ""):
-            l = [int(n) * thick for n in name.split(",")]
-            length = " ".join(str(n) for n in l)
-        else:
-            length = None
-
-        return length
-
     def path(self, pd, **kwargs):
-        thick = kwargs.get('thick')
         fill = kwargs.get('fill')
         outline = kwargs.get('outline')
-        style = kwargs.get('style')
-        _filter = kwargs.get('filter')
 
-        p = path(pd, fill=self.rgb(fill), stroke=self.rgb(outline),
-                 stroke_dasharray=self.style(style, thick),
-                 style=self.filter(_filter))
+        p = path(pd, fill=rgb(fill), stroke=rgb(outline),
+                 **drawing_params(kwargs))
         self.svg.addElement(p)
 
     def rectangle(self, box, **kwargs):
         thick = kwargs.get('thick')
         fill = kwargs.get('fill', 'none')
         outline = kwargs.get('outline')
-        style = kwargs.get('style')
-        _filter = kwargs.get('filter')
 
-        x = box[0]
-        y = box[1]
-        width = box[2] - box[0]
-        height = box[3] - box[1]
-
-        r = rect(x, y, width, height, fill=self.rgb(fill),
-                 stroke=self.rgb(outline), stroke_width=thick,
-                 stroke_dasharray=self.style(style, thick),
-                 style=self.filter(_filter))
+        r = rect(box.x, box.y, box.width, box.height,
+                 fill=rgb(fill), stroke=rgb(outline),
+                 stroke_width=thick, **drawing_params(kwargs))
         self.svg.addElement(r)
 
-    def textsize(self, string, font, maxwidth=None, **kwargs):
-        if maxwidth is None:
-            maxwidth = 65535
-
-        box = Box(0, 0, maxwidth, 65535)
-        textbox = textfolder.get(self, box, string, font,
-                                 adjustBaseline=True, **kwargs)
-        return textbox.outlinebox.size
-
     @cached
     def textlinesize(self, string, font, **kwargs):
         if kwargs.get('ignore_pil', self.ignore_pil):
@@ -119,92 +117,85 @@ class SVGImageDrawElement(_base.ImageDraw):
 
             return self._pil_drawer.textlinesize(string, font)
 
-    def text(self, xy, string, font, **kwargs):
+    def text(self, point, string, font, **kwargs):
         fill = kwargs.get('fill')
 
-        t = text(xy[0], xy[1], string, fill=self.rgb(fill),
+        t = text(point.x, point.y, string, fill=rgb(fill),
                  font_family=font.generic_family, font_size=font.size,
                  font_weight=font.weight, font_style=font.style)
         self.svg.addElement(t)
 
     def textarea(self, box, string, font, **kwargs):
         if 'rotate' in kwargs and kwargs['rotate'] != 0:
-            angle = int(kwargs['rotate']) % 360
-            del kwargs['rotate']
+            self.rotated_textarea(box, string, font, **kwargs)
+        else:
+            lines = self.textfolder(box, string, font, **kwargs)
 
-            if angle in (90, 270):
-                _box = Box(box[0], box[1],
-                           box[0] + box.height, box[1] + box.width)
-                if angle == 90:
-                    _box = _box.shift(x=box.width)
-                elif angle == 270:
-                    _box = _box.shift(y=box.height)
-            elif angle == 180:
-                _box = Box(box[2], box[3],
-                           box[2] + box.width, box[3] + box.height)
-            else:
-                _box = Box(box[0], box[1],
-                           box[0] + box.width, box[1] + box.height)
+            if kwargs.get('outline'):
+                outline = kwargs.get('outline')
+                self.rectangle(lines.outlinebox, fill='white', outline=outline)
 
-            rotate = "rotate(%d,%d,%d)" % (angle, _box[0], _box[1])
-            group = g(transform="%s" % rotate)
-            self.svg.addElement(group)
+            rendered = False
+            for string, point in lines.lines:
+                self.text(point, string, font, **kwargs)
+                rendered = True
 
-            elem = SVGImageDrawElement(group, self)
-            elem.textarea(_box, string, font, **kwargs)
-            return
+            if not rendered and font.size > 0:
+                font.size = int(font.size * 0.8)
+                self.textarea(box, string, font, **kwargs)
 
-        lines = textfolder.get(self, box, string, font,
-                               adjustBaseline=True, **kwargs)
+    def rotated_textarea(self, box, string, font, **kwargs):
+        angle = int(kwargs['rotate']) % 360
+        del kwargs['rotate']
 
-        if kwargs.get('outline'):
-            outline = kwargs.get('outline')
-            self.rectangle(lines.outlinebox, fill='white', outline=outline)
+        if angle in (90, 270):
+            _box = Box(box[0], box[1],
+                       box[0] + box.height, box[1] + box.width)
+            if angle == 90:
+                _box = _box.shift(x=box.width)
+            elif angle == 270:
+                _box = _box.shift(y=box.height)
+        elif angle == 180:
+            _box = Box(box[2], box[3],
+                       box[2] + box.width, box[3] + box.height)
+        else:
+            _box = Box(box[0], box[1],
+                       box[0] + box.width, box[1] + box.height)
 
-        rendered = False
-        for string, xy in lines.lines:
-            self.text(xy, string, font, **kwargs)
-            rendered = True
+        rotate = "rotate(%d,%d,%d)" % (angle, _box[0], _box[1])
+        group = g(transform="%s" % rotate)
+        self.svg.addElement(group)
 
-        if not rendered and font.size > 0:
-            font.size = int(font.size * 0.8)
-            self.textarea(box, string, font, **kwargs)
+        elem = SVGImageDrawElement(group, self)
+        elem.textarea(_box, string, font, **kwargs)
 
-    def line(self, xy, **kwargs):
+    def line(self, points, **kwargs):
         fill = kwargs.get('fill')
-        style = kwargs.get('style')
         thick = kwargs.get('thick')
 
-        pd = pathdata(xy[0].x, xy[0].y)
-        for pt in xy[1:]:
+        pd = pathdata(points[0].x, points[0].y)
+        for pt in points[1:]:
             pd.line(pt.x, pt.y)
 
-        p = path(pd, fill="none", stroke=self.rgb(fill),
-                 stroke_width=thick, stroke_dasharray=self.style(style, thick))
+        p = path(pd, fill="none", stroke=rgb(fill),
+                 stroke_width=thick, **drawing_params(kwargs))
         self.svg.addElement(p)
 
-    def arc(self, xy, start, end, **kwargs):
+    def arc(self, box, start, end, **kwargs):
         thick = kwargs.get('thick')
         fill = kwargs.get('fill')
-        style = kwargs.get('style')
 
-        w = (xy[2] - xy[0]) / 2
-        h = (xy[3] - xy[1]) / 2
+        w = box.width / 2
+        h = box.height / 2
 
         if start > end:
             end += 360
 
-        from blockdiag.utils import ellipse
-
-        coord = ellipse.coordinate(1, w, h, start, start + 1)
-        point = iter(coord).next()
-        pt1 = XY(xy[0] + w + round(point[0], 0),
-                 xy[1] + h + round(point[1], 0))
-
-        coord = ellipse.coordinate(1, w, h, end, end + 1)
-        point = iter(coord).next()
-        pt2 = XY(xy[0] + w + round(point[0], 0),
-                 xy[1] + h + round(point[1], 0))
+        endpoints = ellipse_endpoints(1, w, h, start, end)
+        pt1 = XY(box.x + w + round(endpoints[0].x, 0),
+                 box.y + h + round(endpoints[0].y, 0))
+        pt2 = XY(box.x + w + round(endpoints[1].x, 0),
+                 box.y + h + round(endpoints[1].y, 0))
 
         if end - start > 180:
             largearc = 1
@@ -213,37 +204,28 @@ class SVGImageDrawElement(_base.ImageDraw):
 
         pd = pathdata(pt1[0], pt1[1])
         pd.ellarc(w, h, 0, largearc, 1, pt2[0], pt2[1])
-        p = path(pd, fill="none", stroke=self.rgb(fill),
-                 stroke_dasharray=self.style(style, thick))
+        p = path(pd, fill="none", stroke=rgb(fill),
+                 **drawing_params(kwargs))
         self.svg.addElement(p)
 
-    def ellipse(self, xy, **kwargs):
-        thick = kwargs.get('thick')
+    def ellipse(self, box, **kwargs):
         fill = kwargs.get('fill')
         outline = kwargs.get('outline')
-        style = kwargs.get('style')
-        _filter = kwargs.get('filter')
 
-        w = (xy[2] - xy[0]) / 2
-        h = (xy[3] - xy[1]) / 2
-        pt = XY(xy[0] + w, xy[1] + h)
+        w = box.width / 2
+        h = box.height / 2
+        pt = box.center
 
-        e = ellipse(pt.x, pt.y, w, h, fill=self.rgb(fill),
-                    stroke=self.rgb(outline),
-                    stroke_dasharray=self.style(style, thick),
-                    style=self.filter(_filter))
+        e = ellipse(pt.x, pt.y, w, h, fill=rgb(fill),
+                    stroke=rgb(outline), **drawing_params(kwargs))
         self.svg.addElement(e)
 
-    def polygon(self, xy, **kwargs):
-        thick = kwargs.get('thick')
+    def polygon(self, points, **kwargs):
         fill = kwargs.get('fill')
         outline = kwargs.get('outline')
-        style = kwargs.get('style')
-        _filter = kwargs.get('filter')
 
-        pg = polygon(xy, fill=self.rgb(fill), stroke=self.rgb(outline),
-                     stroke_dasharray=self.style(style, thick),
-                     style=self.filter(_filter))
+        pg = polygon(points, fill=rgb(fill), stroke=rgb(outline),
+                     **drawing_params(kwargs))
         self.svg.addElement(pg)
 
     def image(self, box, url):
