@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
+from blockdiag.tests.utils import __build_diagram, __validate_node_attributes
+
 from blockdiag.utils.collections import defaultdict
-from utils import __build_diagram, __validate_node_attributes
 
 
 def test_single_node_diagram():
