@@ -1,64 +1,65 @@
 # -*- coding: utf-8 -*-
 
-from blockdiag.parser import *
+from blockdiag.parser import parse_string, ParseException
+from blockdiag.parser import Graph, SubGraph, Statements, Node, Edge
 from nose.tools import raises
 
 
 def test_parser_basic():
     # basic digram
-    str = """
-          diagram test {
-             A -> B -> C, D;
-          }
-          """
+    code = """
+           diagram test {
+              A -> B -> C, D;
+           }
+           """
 
-    tree = parse_string(str)
+    tree = parse_string(code)
     assert isinstance(tree, Graph)
 
 
 def test_parser_without_diagram_id():
-    str = """
-          diagram {
-             A -> B -> C, D;
-          }
-          """
-    tree = parse_string(str)
+    code = """
+           diagram {
+              A -> B -> C, D;
+           }
+           """
+    tree = parse_string(code)
     assert isinstance(tree, Graph)
 
-    str = """
-          {
-             A -> B -> C, D;
-          }
-          """
-    tree = parse_string(str)
+    code = """
+           {
+              A -> B -> C, D;
+           }
+           """
+    tree = parse_string(code)
     assert isinstance(tree, Graph)
 
 
 def test_parser_empty_diagram():
-    str = """
-          diagram {
-          }
-          """
-    tree = parse_string(str)
+    code = """
+           diagram {
+           }
+           """
+    tree = parse_string(code)
     assert isinstance(tree, Graph)
 
-    str = """
-          {
-          }
-          """
-    tree = parse_string(str)
+    code = """
+           {
+           }
+           """
+    tree = parse_string(code)
     assert isinstance(tree, Graph)
 
 
 def test_parser_diagram_includes_nodes():
-    str = """
-          diagram {
-            A;
-            B [label = "foobar"];
-            C [color = "red"];
-          }
-          """
-    tree = parse_string(str)
+    code = """
+           diagram {
+             A;
+             B [label = "foobar"];
+             C [color = "red"];
+           }
+           """
+    tree = parse_string(code)
     assert isinstance(tree, Graph)
     assert len(tree.stmts) == 3
     assert isinstance(tree.stmts[0], Statements)
@@ -70,24 +71,24 @@ def test_parser_diagram_includes_nodes():
 
 
 def test_parser_diagram_includes_edges():
-    str = """
-          diagram {
-            A -> B -> C;
-          }
-          """
-    tree = parse_string(str)
+    code = """
+           diagram {
+             A -> B -> C;
+           }
+           """
+    tree = parse_string(code)
     assert isinstance(tree, Graph)
     print tree.stmts
     assert len(tree.stmts) == 1
     assert isinstance(tree.stmts[0], Edge)
 
-    str = """
-          diagram {
-            A -> B -> C [style = dotted];
-            D -> E, F;
-          }
-          """
-    tree = parse_string(str)
+    code = """
+           diagram {
+             A -> B -> C [style = dotted];
+             D -> E, F;
+           }
+           """
+    tree = parse_string(code)
     assert isinstance(tree, Graph)
     print tree.stmts
     assert len(tree.stmts) == 2
@@ -96,17 +97,17 @@ def test_parser_diagram_includes_edges():
 
 
 def test_parser_diagram_includes_groups():
-    str = """
-          diagram {
-            group {
-              A; B;
-            }
-            group {
-              C -> D;
-            }
-          }
-          """
-    tree = parse_string(str)
+    code = """
+           diagram {
+             group {
+               A; B;
+             }
+             group {
+               C -> D;
+             }
+           }
+           """
+    tree = parse_string(code)
     assert isinstance(tree, Graph)
     assert len(tree.stmts) == 2
 
@@ -123,18 +124,18 @@ def test_parser_diagram_includes_groups():
 
 
 def test_parser_diagram_includes_diagram_attributes():
-    str = """
-          diagram {
-            fontsize = 12;
-            node_width = 80;
-          }
-          """
-    tree = parse_string(str)
+    code = """
+           diagram {
+             fontsize = 12;
+             node_width = 80;
+           }
+           """
+    tree = parse_string(code)
     assert isinstance(tree, Graph)
     assert len(tree.stmts) == 2
 
 
 @raises(ParseException)
 def test_parser_parenthesis_ness():
-    str = ""
-    parse_string(str)
+    code = ""
+    parse_string(code)
