@@ -1,14 +1,17 @@
 # -*- coding: utf-8 -*-
 import re
+import sys
 from StringIO import StringIO
 from nose.tools import eq_
-from blockdiag.builder import *
+from blockdiag.builder import ScreenNodeBuilder
 from blockdiag.parser import parse_string
 
 
 def supported_pil():
     try:
         import _imagingft
+        _imagingft
+
         return True
     except:
         return False
@@ -24,6 +27,8 @@ def with_pil(fn):
 def supported_pdf():
     try:
         import reportlab
+        reportlab
+
         return True
     except:
         return False
@@ -91,8 +96,8 @@ def __build_diagram(filename):
     testdir = os.path.dirname(__file__)
     pathname = "%s/diagrams/%s" % (testdir, filename)
 
-    str = open(pathname).read()
-    tree = parse_string(str)
+    code = open(pathname).read()
+    tree = parse_string(code)
     return ScreenNodeBuilder.build(tree)
 
 
