@@ -19,10 +19,11 @@ from docutils import nodes
 from docutils.parsers import rst
 from docutils.statemachine import ViewList
 from blockdiag import parser
-from blockdiag.command import detectfont
 from blockdiag.builder import ScreenNodeBuilder
 from blockdiag.drawer import DiagramDraw
+from blockdiag.utils.bootstrap import detectfont
 from blockdiag.utils.collections import namedtuple
+from blockdiag.utils.rst.nodes import blockdiag
 
 
 directive_options_default = dict(format='PNG',
@@ -60,10 +61,6 @@ def cmp_node_number(a, b):
     return cmp(n1, n2)
 
 
-class blockdiag(nodes.General, nodes.Element):
-    pass
-
-
 class BlockdiagDirectiveBase(rst.Directive):
     """ Directive to insert arbitrary dot markup. """
     name = "blockdiag"
@@ -137,7 +134,10 @@ class BlockdiagDirective(BlockdiagDirectiveBase):
         if not isinstance(node, self.node_class):
             return results
 
-        diagram = self.node2diagram(node)
+        try:
+            diagram = self.node2diagram(node)
+        except Exception, e:
+            raise self.warning(e.message)
 
         if 'desctable' in node['options']:
             del node['options']['desctable']
@@ -162,6 +162,7 @@ class BlockdiagDirective(BlockdiagDirectiveBase):
         return ScreenNodeBuilder.build(tree)
 
     def node2image(self, node, diagram):
+        options = node['options']
         filename = self.image_filename(node)
         fontpath = self.detectfont()
         _format = self.global_options['format'].lower()
@@ -178,13 +179,18 @@ class BlockdiagDirective(BlockdiagDirectiveBase):
             content = drawer.save()
 
             if _format == 'svg' and self.global_options['inline_svg'] is True:
+                size = drawer.pagesize()
+                if 'maxwidth' in options and options['maxwidth'] < size[0]:
+                    ratio = float(options['maxwidth']) / size[0]
+                    new_size = (options['maxwidth'], int(size[1] * ratio))
+                    content = drawer.save(new_size)
+
                 return nodes.raw('', content.decode('utf-8'), format='html')
 
         size = drawer.pagesize()
-        options = node['options']
         if 'maxwidth' in options and options['maxwidth'] < size[0]:
             ratio = float(options['maxwidth']) / size[0]
-            thumb_size = (options['maxwidth'], size[1] * ratio)
+            thumb_size = (options['maxwidth'], int(size[1] * ratio))
 
             thumb_filename = self.image_filename(node, prefix='_thumb')
             if not os.path.isfile(thumb_filename):
